import os
import mario
mario.activate(basedir=os.path.dirname(__file__))
from mario.origin import ProjectModule  # @UnresolvedImport


class ProjectModule(ProjectModule):

    # Attributes

    author = 'roll'
    author_email = 'roll@respect31.com'
    copyright = 'Copyright (c) 2014 Respect31 <post@respect31.com>'
    description = 'Class-based settings for Sphinx.'
    development_requires = ['mario', 'sphinx-settings', 'sphinx-rtd-theme']
    github_user = 'respect31'
    install_requires = ['sphinx', 'sugarbowl']
    interpreters = ['3.3', '3.4']
    license = 'MIT License'
    name = 'sphinx-settings'
    platforms = ['Unix']
    pypi_password_secure = 'Qrtiajld9REXz76NVs7IpwAQhf11mBUNNqmtXL13m4/Qc9dSWHGJabxPjvmVPeCWzUj3ralvmhIRNr0rnWGy68pA0pgomzRPrS2RCIhzHq4e4LWZG3ESkA0LE/Fw0Jnu6Tl4VPPl1MMH074H/XD8nV0aWkBrcN/vqbR81dwaxzk='
    tests_require = ['nose', 'coverage']
    test_suite = 'nose.collector'
    version = '0.1.1'
